Description
============

.. include:: ../../../README.rst
    :start-after: start_include_in_introduction
    :end-before: end_include_in_introduction


A pdf version of the documentation can be found here :download:`DataDigitizer <../../build/latex/datadigitizer.pdf>`

How to install
=================

.. literalinclude:: ../../../INSTALL.txt
    :language: bash

Dependencies
==============

.. literalinclude:: ../../../requirements.txt

License
==========

.. literalinclude:: ../../../LICENSE.txt